==> sparkling-water-ml_2.11-3.32.1.3-1-2.4-sources.jar: ai/h2o/sparkling/ml/algos/H2OGAM.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ai.h2o.sparkling.ml.algos

import ai.h2o.sparkling.ml.params.H2OGAMParams
import ai.h2o.sparkling.ml.utils.H2OParamsReadable
import hex.gam.GAMModel.GAMParameters
import org.apache.spark.ml.util.Identifiable
import ai.h2o.sparkling.ml.models.H2OGAMMOJOModel
import org.apache.spark.sql.Dataset

class H2OGAM(override val uid: String)
  extends H2OSupervisedAlgorithm[GAMParameters]
  with H2OGAMParams
  with FamilyBasedH2OTrainFramePreparation {

  def this() = this(Identifiable.randomUID(classOf[H2OGAM].getSimpleName))

  override def fit(dataset: Dataset[_]): H2OGAMMOJOModel = {
    super.fit(dataset).asInstanceOf[H2OGAMMOJOModel]
  }
}
    
object H2OGAM extends H2OParamsReadable[H2OGAM]

==> sparkling-water-ml_2.12-3.32.1.7-1-3.0-sources.jar: ai/h2o/sparkling/ml/algos/H2OGAM.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ai.h2o.sparkling.ml.algos

import ai.h2o.sparkling.ml.params.H2OGAMParams
import ai.h2o.sparkling.ml.utils.H2OParamsReadable
import hex.gam.GAMModel.GAMParameters
import org.apache.spark.ml.util.Identifiable
import ai.h2o.sparkling.ml.models.H2OGAMMOJOModel
import org.apache.spark.sql.Dataset

class H2OGAM(override val uid: String)
  extends H2OSupervisedAlgorithmWithFoldColumn[GAMParameters]
  with H2OGAMParams
  with FamilyBasedH2OTrainFramePreparation {

  def this() = this(Identifiable.randomUID(classOf[H2OGAM].getSimpleName))

  override def fit(dataset: Dataset[_]): H2OGAMMOJOModel = {
    super.fit(dataset).asInstanceOf[H2OGAMMOJOModel]
  }
}
    
object H2OGAM extends H2OParamsReadable[H2OGAM]
